# flask-sketch

A Python CLI for auto-generate folders structure and boilerplate code for Flask Applications.

## Installation

Flask Sketch is available on PyPi. Simply use pip to install Flask Sketch:

```
pip install flask-sketch
```

## Demo

A simple demo using Flask Sketch

![Alt Text](docs/assets/sketch-demo.gif)
